# ALICE Bot
This is an agent that takes an observation, gets the ALICE bot's response the observation, and wraps it into an action's reply.
The ALICE bot is a strong rule-based bot uing AIML.
The Python implementation of the bot was taken from https://github.com/paulovn/python-aiml.
https://www.pandorabots.com/pandora/talk?botid=b8d616e35e36e881 is a working demo of the bot.

More information: https://en.wikipedia.org/wiki/Artificial_Linguistic_Internet_Computer_Entity

## Setup
```bash
pip install git+https://github.com/paulovn/python-aiml.git
```
